@@ -60,12 +60,12 @@ class Blob(Point, Visible):
         else:
             self.points = []
 
-    def addLabel(self, text, displace=-0.15, angle = 0):
+    def addLabel(self, text, displace=-0.15, angle = 0, size=pyx.text.size.normalsize):
         """Add a label."""
         if config.getOptions().DEBUG:
             print "Adding label: " + text
         self.labels.append(PointLabel(text=text, point=self,
-                                      displace=displace, angle=angle))
+                                      displace=displace, angle=angle, size=size))
         if config.getOptions().DEBUG:
             print "Labels = " + str(self.labels)
         return self
